DateTimePickerAdapter class

Inheritance

Constructors

DateTimePickerAdapter({Picker? picker, int type = 0, bool isNumberMonth = false, List<String>? months = monthsListEN, List<String>? strAMPM, int? yearBegin = 1900, int? yearEnd = 2100, DateTime? value, DateTime? minValue, DateTime? maxValue, int? minHour, int? maxHour, String? secondSuffix, String? minuteSuffix, String? hourSuffix, String? yearSuffix, String? monthSuffix, String? daySuffix, int? minuteInterval, List<int>? customColumnType, bool twoDigitYear = false})

Properties

customColumnType → List<int>?
year 0, month 1, day 2, hour 3, minute 4, sec 5, am/pm 6, hour-ap: 7
final
daySuffix → String?
Year, month, day suffix
final
hashCode → int
The hash code for this object.
no setterinherited
hourSuffix → String?
Year, month, day suffix
final
isLinkage → bool
no setterinherited
isNumberMonth → bool
Whether to display the month in numerical form.If true, months is not used.
final
length → int
Content length of current column
no setterinherited
maxHour → int?
hour min ... max, min >= 0, max <= 23, max > min
final
maxLevel → int
no setterinherited
maxValue → DateTime?
minimum datetime
final
minHour → int?
hour min ... max, min >= 0, max <= 23, max > min
final
minuteInterval → int?
jump minutes, user could select time in intervals of 30min, 5mins, etc....
final
minuteSuffix → String?
Year, month, day suffix
final
minValue → DateTime?
minimum datetime
final
months → List<String>?
custom months strings
final
monthSuffix → String?
Year, month, day suffix
final
picker ↔ Picker?
Reference to the picker widget using this adapter.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondSuffix → String?
Year, month, day suffix
final
strAMPM → List<String>?
Custom AM, PM strings
final
text → String
no setterinherited
twoDigitYear → bool
use two-digit year, 2019, displayed as 19
final
type → int
display type, ref: columnType
final
value ↔ DateTime?
Currently selected value
getter/setter pair
yearBegin → int?
year begin...end.
final
yearEnd → int?
year begin...end.
final
yearSuffix → String?
Year, month, day suffix
final

Methods

buildItem(BuildContext context, int index) → Widget
Builds the widget for a specific item in the current column.
override
doSelect(int column, int index) → void
override
doShow() → void
override
existSec() → bool
getColumnFlex(int column) → int
override
getColumnType(int index) → int
getIsLinkage() → bool
inherited
getLength() → int
Returns the number of items in the current column.
override
getMaxLevel() → int
Returns the maximum number of columns (levels) this adapter supports.
override
getSelectedValues() → List<DateTime>
inherited
getText() → String
override
initSelects() → void
Initializes the selected indices for all columns.
override
intToStr(int v) → String
makeText(Widget? child, String? text, bool isSel) → Widget
inherited
makeTextEx(Widget? child, String text, Widget? postfix, Widget? suffix, bool isSel) → Widget
inherited
needUpdatePrev(int curIndex) → bool
Need to update previous columns
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyDataChanged() → void
Notify adapter of data changes
inherited
setColumn(int index) → void
Sets the active column for subsequent operations.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

columnType → const List<List<int>>
year 0, month 1, day 2, hour 3, minute 4, sec 5, am/pm 6, hour-ap: 7
columnTypeLength → const Map<int, int>
lengths → const List<List<int>>
monthsListEN → const List<String>
monthsListENL → const List<String>