PickerLocalizations class

localizations

Inheritance

Constructors

PickerLocalizations(Locale? locale)
const

Properties

ampm → List?
no setterinherited
cancelText → String?
no setterinherited
confirmText → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
locale → Locale?
finalinherited
months → List?
no setterinherited
monthsLong → List?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getItem(String key) → Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(BuildContext context) → PickerLocalizations
registerCustomLanguage(String name, {String? cancelText, String? confirmText, List<String>? ampm, List<String>? months, List<String>? monthsLong}) → void
Register custom language

Constants

languages → const List<String>
Language Support
localizedValues → const Map<String, Map<String, Object>>
Language Values