PickerLocalizationsBase class abstract

Implementers

Constructors

PickerLocalizationsBase(Locale? locale)
const

Properties

ampm → List?
no setter
cancelText → String?
no setter
confirmText → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
locale → Locale?
final
months → List?
no setter
monthsLong → List?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getItem(String key) → Object?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited